@@ -73,8 +73,9 @@ impl GlobalState {
         fn is_interesting(path: &AbsPath, change_kind: ChangeKind) -> bool {
             const IMPLICIT_TARGET_FILES: &[&str] = &["build.rs", "src/main.rs", "src/lib.rs"];
             const IMPLICIT_TARGET_DIRS: &[&str] = &["src/bin", "examples", "tests", "benches"];
+            let file_name = path.file_name().unwrap_or_default();
 
-            if path.ends_with("Cargo.toml") || path.ends_with("Cargo.lock") {
+            if file_name == "Cargo.toml" || file_name == "Cargo.lock" {
                 return true;
             }
             if change_kind == ChangeKind::Modify {
@@ -83,22 +84,22 @@ impl GlobalState {
             if path.extension().unwrap_or_default() != "rs" {
                 return false;
             }
-            if IMPLICIT_TARGET_FILES.iter().any(|it| path.ends_with(it)) {
+            if IMPLICIT_TARGET_FILES.iter().any(|it| path.as_ref().ends_with(it)) {
                 return true;
             }
             let parent = match path.parent() {
                 Some(it) => it,
                 None => return false,
             };
-            if IMPLICIT_TARGET_DIRS.iter().any(|it| parent.ends_with(it)) {
+            if IMPLICIT_TARGET_DIRS.iter().any(|it| parent.as_ref().ends_with(it)) {
                 return true;
             }
-            if path.ends_with("main.rs") {
+            if file_name == "main.rs" {
                 let grand_parent = match parent.parent() {
                     Some(it) => it,
                     None => return false,
                 };
-                if IMPLICIT_TARGET_DIRS.iter().any(|it| grand_parent.ends_with(it)) {
+                if IMPLICIT_TARGET_DIRS.iter().any(|it| grand_parent.as_ref().ends_with(it)) {
                     return true;
                 }
             }
